[FFmpeg-cvslog] fix spelling errors

Andreas Cadhalpun git at videolan.org
Fri Mar 6 21:44:38 CET 2015


ffmpeg | branch: master | Andreas Cadhalpun <Andreas.Cadhalpun at googlemail.com> | Fri Mar  6 20:26:32 2015 +0100| [482c86f2319c73a0ea414a1845de58febf7b0e30] | committer: Michael Niedermayer

fix spelling errors

 opttimizations -> optimizations
 grabing        -> grabbing
 many resource  -> many resources
 isnt           -> isn't
 silcense       -> silence

Signed-off-by: Andreas Cadhalpun <Andreas.Cadhalpun at googlemail.com>
Signed-off-by: Michael Niedermayer <michaelni at gmx.at>

> http://git.videolan.org/gitweb.cgi/ffmpeg.git/?a=commit;h=482c86f2319c73a0ea414a1845de58febf7b0e30
---

 Changelog           |    2 +-
 doc/indevs.texi     |    2 +-
 doc/protocols.texi  |   10 +++++-----
 libavdevice/v4l2.c  |    2 +-
 libavformat/cache.c |    4 ++--
 libavformat/rmdec.c |    2 +-
 6 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/Changelog b/Changelog
index 55484b7..640b14d 100644
--- a/Changelog
+++ b/Changelog
@@ -39,7 +39,7 @@ version 2.6:
 - Canopus HQX decoder
 - RTP depacketization of T.140 text (RFC 4103)
 - VP9 RTP payload format (draft 0) experimental depacketizer
-- Port MIPS opttimizations to 64-bit
+- Port MIPS optimizations to 64-bit
 
 
 version 2.5:
diff --git a/doc/indevs.texi b/doc/indevs.texi
index 1a49293..ccbb39a 100644
--- a/doc/indevs.texi
+++ b/doc/indevs.texi
@@ -1109,7 +1109,7 @@ The syntax is:
 -grab_x @var{x_offset} -grab_y @var{y_offset}
 @end example
 
-Set the grabing region coordinates. The are expressed as offset from the top left
+Set the grabbing region coordinates. They are expressed as offset from the top left
 corner of the X11 window. The default value is 0.
 
 @section decklink
diff --git a/doc/protocols.texi b/doc/protocols.texi
index 006324c..5f6dfa8 100644
--- a/doc/protocols.texi
+++ b/doc/protocols.texi
@@ -63,7 +63,7 @@ cache:@var{URL}
 
 Physical concatenation protocol.
 
-Allow to read and seek from many resource in sequence as if they were
+Read and seek from many resources in sequence as if they were
 a unique resource.
 
 A URL accepted by this protocol has the syntax:
@@ -117,7 +117,7 @@ ffmpeg -i "data:image/gif;base64,R0lGODdhCAAIAMIEAAAAAAAA//8AAP//AP/////////////
 
 File access protocol.
 
-Allow to read from or write to a file.
+Read from or write to a file.
 
 A file URL can have the form:
 @example
@@ -155,7 +155,7 @@ time, which is valuable for files on slow medium.
 
 FTP (File Transfer Protocol).
 
-Allow to read from or write to remote resources using FTP protocol.
+Read from or write to remote resources using FTP protocol.
 
 Following syntax is required.
 @example
@@ -374,7 +374,7 @@ be seekable, so they will fail with the MD5 output protocol.
 
 UNIX pipe access protocol.
 
-Allow to read and write from UNIX pipes.
+Read and write from UNIX pipes.
 
 The accepted syntax is:
 @example
@@ -614,7 +614,7 @@ For more information see: @url{http://www.samba.org/}.
 
 Secure File Transfer Protocol via libssh
 
-Allow to read from or write to remote resources using SFTP protocol.
+Read from or write to remote resources using SFTP protocol.
 
 Following syntax is required.
 
diff --git a/libavdevice/v4l2.c b/libavdevice/v4l2.c
index 0f64d74..fba7764 100644
--- a/libavdevice/v4l2.c
+++ b/libavdevice/v4l2.c
@@ -747,7 +747,7 @@ static int v4l2_set_parameters(AVFormatContext *ctx)
             }
         } else {
             av_log(ctx, AV_LOG_WARNING,
-                   "The driver does not allow to change time per frame\n");
+                   "The driver does not permit changing the time per frame\n");
         }
     }
     if (tpf->denominator > 0 && tpf->numerator > 0) {
diff --git a/libavformat/rmdec.c b/libavformat/rmdec.c
index 9468d97..727d065 100644
--- a/libavformat/rmdec.c
+++ b/libavformat/rmdec.c
@@ -708,7 +708,7 @@ static int rm_assemble_video_frame(AVFormatContext *s, AVIOContext *pb,
                                    int64_t *timestamp)
 {
     int hdr;
-    int seq = 0, pic_num = 0, len2 = 0, pos = 0; //init to silcense compiler warning
+    int seq = 0, pic_num = 0, len2 = 0, pos = 0; //init to silence compiler warning
     int type;
     int ret;
 



More information about the ffmpeg-cvslog mailing list
diff --git a/libavformat/cache.c b/libavformat/cache.c
index 26e68c5..d3d12bb 100644
--- a/libavformat/cache.c
+++ b/libavformat/cache.c
@@ -145,7 +145,7 @@ static int add_entry(URLContext *h, const unsigned char *buf, int size)
 
     return 0;
 fail:
     //we could truncate the file to pos here if pos >=0 but ftruncate isnt available in VS so
     //for simplicty we just leave the file a bit larger
     av_free(entry);
     av_free(node);
@@ -300,7 +300,7 @@ static int cache_close(URLContext *h)
 #define D AV_OPT_FLAG_DECODING_PARAM
 
 static const AVOption options[] = {
-    { "read_ahead_limit", "Amount in bytes that may be read ahead when seeking isnt supported, -1 for unlimited", OFFSET(read_ahead_limit), AV_OPT_TYPE_INT, { .i64 = 65536 }, -1, INT_MAX, D },
+    { "read_ahead_limit", "Amount in bytes that may be read ahead when seeking isn't supported, -1 for unlimited", OFFSET(read_ahead_limit), AV_OPT_TYPE_INT, { .i64 = 65536 }, -1, INT_MAX, D },
     {NULL},
 };
 
@@ -145,7 +145,7 @@ static int add_entry(URLContext *h, const unsigned char *buf, int size)
     return 0;
 fail:
-    //we could truncate the file to pos here if pos >=0 but ftruncate isnt available in VS so
+    //we could truncate the file to pos here if pos >=0 but ftruncate isn't available in VS so
     //for simplicty we just leave the file a bit larger
     av_free(entry);